@@ -1,5 +1,6 @@
 package Barcode::Code93;
-use Any::Moose;
+use strict; use warnings;
+use Moo;
 
 =head1 NAME
 
@@ -7,7 +8,7 @@ Barcode::Code93 - Generate data for Code 93 barcodes
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -16,6 +17,13 @@ our $VERSION = '0.02';
     my $data = Barcode::Code93->new->barcode('MONKEY');
     print for map { $_ ? "#" : ' ' } @$data;
 
+=head1 DESCRIPTION
+
+This class is used to generate data for Code 93 barcodes. It is primarily
+useful as a data source for barcode modules that do rendering,
+such as L<HTML::Barcode::Code93>.  You can easily make a version that
+renders an image, PDF, or anything else.
+
 =head1 METHODS
 
 =head2 new
@@ -42,6 +50,8 @@ Chris DiMartino C<<chris DOT dimartino AT gmail DOT com>> (L<GD::Barcode::Code93
 
 Mark A. Stratman, C<< <stratman at gmail.com> >>
 
+Jan Bieron L<https://github.com/bieron>
+
 =head1 CONTRIBUTERS
 
 The L<GD::Barcode::Code93> module, from which this module originates, was based on code provided by Kawai Takanori. Japan.
@@ -79,10 +89,9 @@ See http://dev.perl.org/licenses/ for more information.
 # barcode (from GD::Barcode::Code93)
 #------------------------------------------------------------------------------
 sub _barcode {
-    my $self = shift;
-    my $text = shift;
+    my ($self, $text) = @_;
 
-    my $code93bar = {
+    my %code93bar = (
         0   =>'100010100',
         1   =>'101001000',
         2   =>'101000100',
@@ -131,11 +140,11 @@ sub _barcode {
        '.'  =>'111010100',
        '/'  =>'101101110',
        '*'  =>'101011110',  ##Start/Stop
-    };
+    );
 
     my @sum_text = ('*', $self->calculateSums($text), '*');
 
-    my @rv = map { split //, $code93bar->{$_} } @sum_text;
+    my @rv = map { split //, $code93bar{$_} } @sum_text;
     push @rv, 1;
     return @rv;
 }
@@ -145,8 +154,7 @@ sub _barcode {
 # calculateSums (from GD::Barcode::Code93)
 #-----------------------------------------------------------------------------
 sub calculateSums {
-    my $self = shift;
-    my $text = shift;
+    my ($self, $text) = @_;
     $text = '' unless defined $text;
     my @array = split(//, scalar reverse $text);
 
@@ -202,24 +210,21 @@ sub calculateSums {
     );
 
     my %invCode93Values = reverse %code93values;
-    my $weighted_sum;
 
-    foreach my $counter ( qw/4 3/ ) {
-        for (my $i = 0, my $x = 1; $i <= $#array; $i++, $x++) {
-            my $letter  = $array[$i];
-
-            if ($x > ($counter * 5)) { $x = 1 }
+    foreach my $counter (20, 15) {
+        my $weighted_sum = 0;
+        my $x = 1;
+        foreach my $letter (@array) {
+            if ($x > $counter) { $x = 1 }
             $weighted_sum += ($code93values{$letter} * $x);
+            $x++;
         }
 
         my $check = $invCode93Values{($weighted_sum % 47)};
         unshift @array, $check;
-        $weighted_sum = ();
     }
 
     return reverse @array;
 }
 
-no Any::Moose;
-
 1;
